static char rcsid[] = "$Id: parse.c,v 1.6 2001/04/25 17:17:04 mhucka Exp $";

/*
** $Log: parse.c,v $
** Revision 1.6  2001/04/25 17:17:04  mhucka
** Misc. small changes to improve portability and address compiler warnings.
**
** Revision 1.4  2000/09/21 19:41:10  mhucka
** Added function declarations where appropriate.
**
** Revision 1.3  2000/07/12 06:14:04  mhucka
** Added #include of malloc.h.
**
** Revision 1.2  1996/05/23 23:16:59  dhb
** t3d/e port
**
** Revision 1.1  1992/12/11  19:05:04  dhb
** Initial revision
**
*/

#include <stdio.h>
#include <errno.h>
#include <malloc.h>
#include <stdlib.h>
#include "parse.h"
#include "system_deps.h"

/*
** parse.c
**
**	Routines involved in parse tree construction.
*/

extern int errno;

ParseNode *PTNew(type, data, left, right)

int		type;
ResultValue	data;
ParseNode	*left;
ParseNode	*right;

{	/* PTNew --- Make a new parse tree node and initialze fields */

        extern SIGTYPE sig_msg_restore_context();
	ParseNode	*pn;

	pn = (ParseNode *) malloc(sizeof(ParseNode));
	if (pn == NULL)
	  {
	    perror("PTNew");
	    sig_msg_restore_context(0, errno);
	    /* No Return */
	  }

	pn->pn_val.r_type = type;
	pn->pn_val.r = data;
	pn->pn_left = left;
	pn->pn_right = right;

	return(pn);

}	/* PTNew */


PTFree(pn)

ParseNode	*pn;

{	/* PTFree --- Free an entire parse tree given root */

        int PTFree();

	if (pn != NULL)
	  {
	    PTFree(pn->pn_left);
	    PTFree(pn->pn_right);
	    free(pn);
	  }

}	/* PTFree */
